package com.tong.redispool;

import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import redis.clients.jedis.Jedis;

import java.util.concurrent.CountDownLatch;

@SpringBootTest
class RedisPoolApplicationTests {

    @Autowired
    private IRedisPool pool;
    private final static int THREAD_NUM = 100;
    private CountDownLatch cdl = new CountDownLatch(THREAD_NUM);

    @Test
    public void test() throws Exception {
        //连接池的初始化
        pool.init(20, 2000);
        //模拟并发的场景，对redis进行一些操作。目的是分析连接池中是否只创建了指定的连接数
        for (int i = 0; i < THREAD_NUM; i++) {
            new Thread(new Runnable() {
                @Override
                public void run() {

                    try {
                        cdl.await(); //等待一个指令，所有的等待线程同时执行
                    } catch (InterruptedException e) {
                        e.printStackTrace();
                    }

                    Jedis jedis = null;
                    try {
                        jedis = pool.getResource();
                        jedis.incr("pooltest.incr");
                    } catch (Exception e) {
                        e.printStackTrace();
                    }finally {
                        pool.release(jedis);
                    }
                }
            }).start();
            cdl.countDown(); //计数 -1 0唤醒所有等待的线程
        }
        Thread.sleep(2000);
    }

    @Test
    void contextLoads() {
    }

}
